        function getT(rr,cc){
       if(rr==1 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==1 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 26 <strong>control</strong><br>0,1,3,5,6,9,10,11,12,13,15,17,18,19,22,23,24,30,32,34,44,45,46,48,49,50';}
       if(rr==1 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 25 <br>2,4,7,8,14,16,20,21,25,26,27,28,29,31,33,35,36,37,38,39,40,41,42,43,47';}
       if(rr==8 && cc==0){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==8 && cc==1){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 26 <strong>control</strong><br>0,1,3,5,6,9,10,11,12,13,15,17,18,19,22,23,24,30,32,34,44,45,46,48,49,50';}
       if(rr==8 && cc==2){return '<strong>Temperatura en 850 hPa (C) y Presion en Superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 25 <br>2,4,7,8,14,16,20,21,25,26,27,28,29,31,33,35,36,37,38,39,40,41,42,43,47';}
       if(rr==18 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==18 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 26 <strong>control</strong><br>0,1,3,5,6,9,10,11,12,13,15,17,18,19,22,23,24,30,32,34,44,45,46,48,49,50';}
       if(rr==18 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 25 <br>2,4,7,8,14,16,20,21,25,26,27,28,29,31,33,35,36,37,38,39,40,41,42,43,47';}
       if(rr==24 && cc==0){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==24 && cc==1){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 26 <strong>control</strong><br>0,1,3,5,6,9,10,11,12,13,15,17,18,19,22,23,24,30,32,34,44,45,46,48,49,50';}
       if(rr==24 && cc==2){return '<strong>Probabilidad de nieve acumulada de 0 a 24 UTC superior a 1 mm de agua equivalente</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 25 <br>2,4,7,8,14,16,20,21,25,26,27,28,29,31,33,35,36,37,38,39,40,41,42,43,47';}
       if(rr==44 && cc==0){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==44 && cc==1){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 26 <strong>control</strong><br>0,1,3,5,6,9,10,11,12,13,15,17,18,19,22,23,24,30,32,34,44,45,46,48,49,50';}
       if(rr==44 && cc==2){return '<strong>Desviacion estandar e isohipsas de altura geopotencial (m) en 500 hPa</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 25 <br>2,4,7,8,14,16,20,21,25,26,27,28,29,31,33,35,36,37,38,39,40,41,42,43,47';}
       if(rr==45 && cc==0){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br><strong>control +<br>EPS</strong>';}
       if(rr==45 && cc==1){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>1</strong> representante: <strong>19</strong> miembros: 26 <strong>control</strong><br>0,1,3,5,6,9,10,11,12,13,15,17,18,19,22,23,24,30,32,34,44,45,46,48,49,50';}
       if(rr==45 && cc==2){return '<strong>Spaguetti de presion en superficie (hPa)</strong><br><br><strong>20260531 a 12</strong> UTC HH+144 (rango:132-156)<br>grupo: <strong>2</strong> representante: <strong>4</strong> miembros: 25 <br>2,4,7,8,14,16,20,21,25,26,27,28,29,31,33,35,36,37,38,39,40,41,42,43,47';}
}
