            table, caption, tbody, tfoot, thead, tr, th, td, figure, figcaption, footer, header, hgroup, time, mark, audio, video {
                margin: 0;
                padding: 0;
                border: 0;
                font-size: 100%;
                font: inherit;
                vertical-align: baseline;}
            article, aside, details, figcaption, figure, footer, header, hgroup, menu, nav, section {
                display: block;}
            body {
                line-height: 1;}
            #largeImgPanel {
                text-align: center;
                visibility: hidden;
                position: fixed;
                z-index: 100;
                top: 0; left: 0; width: 100%; height: 100%;
                background-color: rgba(100,100,100, 0.5);}
            #largeSubDiv{
                position: absolute;
                width:100%;
                height:100%;
                background-color: rgb(255,255,255,0.85);}
            .thumbborder{
                object-fit: contain;
                width: 100%;
                height: 100%;
                max-width: 400px;
                max-height: 360px;}
            .tdhead{
                font: italic bold 12px/30px Georgia, serif;
                text-align: center;}
