        table, caption, tbody, tfoot, thead, tr, th, td, figure, figcaption, footer, header, hgroup, time, mark, audio, video {
            margin: 0;
            padding: 0;
            border: 0;
            font-size: 100%;
            font: inherit;
            vertical-align: baseline;}
        article, aside, details, figcaption, figure, footer, header, hgroup, menu, nav, section {
            display: block;}
        body {
            line-height: 1;}
        .aaa0{
            border-right: 2px solid #555555;}
        .hhh1{
            width: 200px;
            max-height: 180px;}
        .hhh0{
            width: 200px;
            max-height: 180px;
            border-right: 2px solid #555555;
            border-left: 2px solid #555555;
            border-bottom: 2px solid #555555;
            border-top: 2px solid #555555;}
        #largeImgPanel {
            text-align: center;
            visibility: hidden;
            position: fixed;
            z-index: 100;
            top: 0; left: 0; width: 100%; height: 100%;
            background-color: rgba(100,100,100, 0.5);}
        #largeSubDiv{
            position: absolute;
            width:100%;
            height:100%;
            background-color: rgb(255,255,255,0.85);}
        .thumbborder{
            object-fit: contain;
            width: 100%;
            height: 100%;
            max-width: 200px;
            max-height: 180px;}
